@@ -43,9 +43,8 @@ package CanvasBezierCurve;
 
 use strict;
 use Carp;
+use Glib qw(TRUE FALSE);
 use Gnome2::Canvas;
-use constant TRUE => 1;
-use constant FALSE => !TRUE;
 
 use constant STATE_INIT          => 0;
 use constant STATE_FIRST_PRESS   => 1;
@@ -82,13 +81,13 @@ sub draw_curve {
 						$root,
 						'Gnome2::Canvas::Bpath',
 			###			can't do this here, see below
-						bpath => $path_def,
+			###			bpath => $path_def,
 						outline_color => 'blue',
 						width_pixels => 5,
 						cap_style => 'round');
 
 			# hack, see above
-##			$current_item->set_path_def ($path_def);
+			$current_item->set_path_def ($path_def);
 
 			$current_item->signal_connect (event => \&item_event);
 		}
@@ -105,12 +104,10 @@ sub draw_curve {
 				    $current_points[4], $current_points[5],
 				    $current_points[2], $current_points[3]);
 
-		$current_item->set (bpath => $path_def);
-		###$current_item->set_path_def ($path_def);
+		###$current_item->set (bpath => $path_def);
+		$current_item->set_path_def ($path_def);
 
 	} elsif ($current_state == STATE_SECOND_PRESS) {
-		#g_assert (current_item);
-
 		$current_points[6] = $x;
 		$current_points[7] = $y;
 
@@ -122,8 +119,8 @@ sub draw_curve {
 				    $current_points[6], $current_points[7],
 				    $current_points[2], $current_points[3]);
 
-		$current_item->set (bpath => $path_def);
-		#$current_item->set_path_def ($path_def);
+		####$current_item->set (bpath => $path_def);
+		$current_item->set_path_def ($path_def);
 
 		$current_item = undef;
 
